document.addEventListener('DOMContentLoaded', function () {
   const forms = document.querySelectorAll('.grata-form');

   forms.forEach(function (form) {
      const messageBlock = form.querySelector('.grata-form-message');

      form.addEventListener('submit', function (event) {
         event.preventDefault();

         // Get UI element
         const errorMessages = form.querySelectorAll('.grata-error-message');
         const phoneInput = form.querySelector('#user-phone');
         const sendButton = form.querySelector('.grata-button');

         messageBlock.classList.remove('show', 'error', 'success');

         // Clearing previous error messages
         errorMessages.forEach(el => el.textContent = '');

         // Check for only digits for the phone number if the field is not empty
         const phoneValue = phoneInput.value.replace(/[ \-\(\)]/g, '');

         // Checking the length of the phone number
         if (phoneValue.length < 10) {
            event.preventDefault();
            messageBlock.textContent = 'Номер телефона должен содержать минимум 10 цифр.';
            messageBlock.classList.add('show', 'error');
            return;
         }

         // Disable the send button
         sendButton.classList.add('disabled');

         //Create Form Data
         const formData = new FormData(form);
         formData.append('user_phone', phoneValue);

         fetch(form.action, {
            method: 'POST',
            body: formData
         })
            .then(response => response.json())
            .then(data => {

               // Enable the send button again
               sendButton.classList.remove('disabled');

               if (data.success) {
                  // Redirected to the thank-you page
                  window.location.href = '/thank-you';

                  // fbq('track', 'Lead')
                  // console.log('Lead')
                  form.reset(); // Clear the form


                  // Replace the HTML content
                  // form.innerHTML = '<section class="grata-section grata-thanks">\
                  //    <div class="grata-container">\
                  //       <div class="data-wrapper">\
                  //          <h1 class="data-title">\
                  //             Спасибо, ваша заявка успешно отправлена\
                  //          </h1>\
                  //          <div class="data-subtitle">\
                  //             Наш менеджер свяжется с вами в ближайшее время\
                  //          </div>\
                  //       </div>\
                  //    </div>\
                  // </section>';

               } else {
                  // Error handling
                  let hasErrors = false;
                  for (const [field, error] of Object.entries(data.errors)) {
                     const errorMessageElement = form.querySelector(`#${field} ~ .grata-error-message`);
                     if (errorMessageElement) {
                        errorMessageElement.textContent = error;
                        hasErrors = true;
                     }
                  }
                  if (hasErrors) {
                     messageBlock.textContent = '';
                  } else {
                     messageBlock.textContent = 'Форма не была отправлена. Попробуйте позже';
                     messageBlock.classList.add('show', 'error');
                  }
               }
            })
            .catch(error => {
               // Enable the send button again
               sendButton.classList.remove('disabled');

               messageBlock.textContent = 'Форма не была отправлена. Попробуйте позже';
               messageBlock.classList.add('show', 'error');
            });
      });
   });
});